@@ -1,6 +1,6 @@
 from scrapeanything.scraper.scraper import Scraper
 
-import undetected_chromedriver.v2 as webdriver
+# import undetected_chromedriver.v2 as webdriver
 from selenium import webdriver
 
 from selenium.webdriver.common.keys import Keys
@@ -51,7 +51,7 @@ class Selenium(Scraper):
 
         options.add_argument('--disable-blink-features=AutomationControlled') # new
         options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36") # new
-        options.add_argument("user-data-dir=C:\\Users\\LCADM.G.Gargiuolo\\AppData\\Local\\Google\\Chrome\\User Data\\Default") # new
+        # options.add_argument("user-data-dir=C:\\Users\\LCADM.G.Gargiuolo\\AppData\\Local\\Google\\Chrome\\User Data\\Default") # new
 
 
         if platform.system() == 'Windows':
