@@ -2,12 +2,12 @@ from configparser import ConfigParser
 
 class Config:
 
-    def __init__(self, path):
+    def __init__(self, path: str):
         self.config = ConfigParser()
         # read config.ini file
         self.config.read(path)
 
-    def get(self, section, key, default=None):
+    def get(self, section: str, key: str, default: any=None):
         # get config value
         if section in self.config and key in self.config[section]:
             return self.config[section][key]
